@@ -2,7 +2,7 @@ import typing
 import time
 
 
-class AssertMixin(object):
+class MixinAssertMixin(object):
     """
     用于单元测试
     """
@@ -36,20 +36,3 @@ class AssertMixin(object):
             if ret:
                 break
             time.sleep(0.05)
-
-
-class RecordMixin(object):
-    """
-    一般用于单元测试
-    """
-    @classmethod
-    def record_mixin_attrs_get(cls, record, dict_or_keys):
-        def get_field(name):
-            if isinstance(record, dict):
-                return record[name]
-            return getattr(record, name)
-        if isinstance(dict_or_keys, dict):
-            dict_or_keys = list(dict_or_keys.keys())
-        dict_or_keys = list(dict_or_keys)
-        d = {key: get_field(key) for key in dict_or_keys}
-        return d
